@@ -115,7 +115,7 @@ void _debug_init(char* fname) {
 void _debug_msg_info(int line, char* file, int type) {
   char *x;
   if (debug_fp == NULL) {
-    fprintf(stderr, "debug_fp is NULL\n");
+    /* fprintf(stderr, "debug_fp is NULL\n"); */
     return;
   }
   info_ptr = (struct _debug_item*) xmalloc(sizeof(struct _debug_item));
@@ -409,6 +409,8 @@ void _debug_write_hex(struct _debug_item *item, unsigned char *buf, int size, in
   int index_pos, file_pos;
   char zero='\0';
   index[0] = 1; // only one item in this index run
+  index[1] = 0; // Unused
+  index[2] = 0; // Unused
   index_pos = ftell(debug_fp);
   fwrite(index, index_size, 1, debug_fp);
   index[1] = ftell(debug_fp);
@@ -421,6 +423,7 @@ void _debug_write_hex(struct _debug_item *item, unsigned char *buf, int size, in
   lfile_rec.funcname = 0;
   lfile_rec.filename = strlen(item->function)+1;
   lfile_rec.text = lfile_rec.filename+strlen(item->file)+1;
+  lfile_rec.end = 0; // Unused
   fwrite(&lfile_rec, sizeof(lfile_rec), 1, debug_fp);
 
   file_pos = ftell(debug_fp);
@@ -437,6 +440,7 @@ void _debug_write_hex(struct _debug_item *item, unsigned char *buf, int size, in
   fwrite(&rec_type, 1, sizeof(char), debug_fp);
   fwrite(&lfile_rec, sizeof(lfile_rec), 1, debug_fp);
   fseek(debug_fp, 0, SEEK_END);
+  free(index);
 }
   
 void * xmalloc(size_t size) {
