@@ -1200,7 +1200,7 @@ char *removeCR (char *c) {
 }
 // }}}1
 // int usage() {{{1
-int usage() {
+int32_t usage() {
   DEBUG_ENT("usage");
   version();
   printf("Usage: %s [OPTIONS] {PST FILENAME}\n", prog_name);
@@ -1221,7 +1221,7 @@ int usage() {
 }
 // }}}1
 // int version() {{{1
-int version() {
+int32_t version() {
   DEBUG_ENT("version");
   printf("ReadPST v%s.\n", VERSION);
 #if BYTE_ORDER == BIG_ENDIAN
@@ -1278,7 +1278,7 @@ char *mk_kmail_dir(char *fname) {
 }
 // }}}1
 // int close_kmail_dir() {{{1
-int close_kmail_dir() {
+int32_t close_kmail_dir() {
   // change ..
   int x;
   DEBUG_ENT("close_kmail_dir");
@@ -1321,7 +1321,7 @@ char *mk_recurse_dir(char *dir) {
 }
 // }}}1
 // int close_recurse_dir() {{{1
-int close_recurse_dir() {
+int32_t close_recurse_dir() {
   int x;
   DEBUG_ENT("close_recurse_dir");
   if (chdir("..")) {
@@ -1401,7 +1401,7 @@ char *mk_seperate_dir(char *dir, int overwrite) {
 }
 // }}}1
 // int close_seperate_dir() {{{1
-int close_seperate_dir() {
+int32_t close_seperate_dir() {
   int x;
   DEBUG_ENT("close_seperate_dir");
   if (chdir("..")) {
@@ -1413,7 +1413,7 @@ int close_seperate_dir() {
 }
 // }}}1
 // int mk_seperate_file(struct file_ll *f) {{{1
-int mk_seperate_file(struct file_ll *f) {
+int32_t mk_seperate_file(struct file_ll *f) {
   DEBUG_ENT("mk_seperate_file");
   DEBUG_MAIN(("mk_seperate_file: opening next file to save email\n"));
   if (f->email_count > 999999999) { // bigger than nine 9's
@@ -1532,7 +1532,7 @@ char *rfc2426_escape(char *str) {
 }
 // }}}1
 // int chr_count(char *str, char x) {{{1
-int chr_count(char *str, char x) {
+int32_t chr_count(char *str, char x) {
   int r = 0;
   while (*str != '\0') {
     if (*str == x)
